/*
 * Copyright (c) 2015 Meltytech, LLC
 * Author: Amy Dennedy
 *
 * Modified by Paul 05 April 2019
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import QtQuick.Controls 1.1
import QtQuick.Layouts 1.1
import Shotcut.Controls 1.0

Item {
    
    property string GlitchFreq: '0'
    property string BlockH: '1'
    property string ShiftInt: '2'
    property string ColorInt: '3'
    
    property double GlitchFreqDefault: 0.0000
    property double BlockHDefault: 0.4991
    property double ShiftIntDefault: 0.4993
    property double ColorIntDefault: 0.0000
    
    property var defaultParameters: ['GlitchFreq', 'BlockH', 'ShiftInt', 'ColorInt']
    
    width: 350
    height: 150
    
    Component.onCompleted: {
        if (filter.isNew) {
            filter.set('GlitchFreq', GlitchFreqDefault)
            filter.set('BlockH', BlockHDefault)
            filter.set('ShiftInt', ShiftIntDefault)
            filter.set('ColorInt', ColorIntDefault)
            //filter.savePreset(preset.defaultParameters)
        }
            setControls()
    }

    function setControls() {
        GlitchFreqSlider.value = filter.getDouble('GlitchFreq')
        BlockHSlider.value = filter.getDouble('BlockH')
        ShiftIntSlider.value = filter.getDouble('ShiftInt')
        ColorIntSlider.value = filter.getDouble('ColorInt')
    }

    GridLayout {
        anchors.fill: parent
        anchors.margins: 8
        columns: 3

        Label {
            text: qsTr('Preset')
            Layout.alignment: Qt.AlignRight
        }
        Preset {
            id: preset
            parameters: ['GlitchFreq', 'BlockH', 'ShiftInt', 'ColorInt']
            Layout.columnSpan: 2
            onPresetSelected: setControls()
        }

        Label {
            text: qsTr('GlitchFreq')
            Layout.alignment: Qt.AlignRight
        }
        SliderSpinner {
            id: GlitchFreqSlider
            minimumValue: 0
            maximumValue: 1
            decimals: 4
            value: filter.getDouble('GlitchFreq')
            onValueChanged: filter.set('GlitchFreq', value)
        }
        UndoButton {
            onClicked: GlitchFreqSlider.value = GlitchFreqDefault
        }

        Label {
            text: qsTr('BlockH')
            Layout.alignment: Qt.AlignRight
        }
        SliderSpinner {
            id: BlockHSlider
            minimumValue: 0
            maximumValue: 1
            decimals: 4
            value: filter.getDouble('BlockH')
            onValueChanged: filter.set('BlockH', value)
            }
        UndoButton {
            onClicked: BlockHSlider.value = BlockHDefault
        }

        Label {
            text: qsTr('ShiftInt')
            Layout.alignment: Qt.AlignRight
        }
        SliderSpinner {
            id: ShiftIntSlider
            minimumValue: 0
            maximumValue: 1
            decimals: 4
            value: filter.getDouble('ShiftInt')
            onValueChanged: filter.set('ShiftInt', value)
        }
        UndoButton {
            onClicked: ShiftIntSlider.value = ShiftIntDefault
        }

        Label {
            text: qsTr('ColorInt')
            Layout.alignment: Qt.AlignRight
        }
        SliderSpinner {
            id: ColorIntSlider
            minimumValue: 0
            maximumValue: 1
            decimals: 4
            value: filter.getDouble('ColorInt')
            onValueChanged: filter.set('ColorInt', value)
        }
        UndoButton {
            onClicked: ColorIntSlider.value = ColorIntDefault
        }

        Item {
            Layout.fillHeight: true;
        }
    }
    Connections {
        target: producer
        onPositionChanged: setControls()
    }
  }
